// Copyright 2022 Michal Przanowski <mike.przanowski@galacticgames.com>

#pragma once

#include "Kismet/BlueprintFunctionLibrary.h"
#include "PlatformFunctionsBPLibrary.generated.h"

/* 
*	Platform Functions Blueprint Library class.
*		Extends Blueprints with extra settings.
*/
UCLASS()
class UPlatformFunctionsBPLibrary : public UBlueprintFunctionLibrary
{
	GENERATED_UCLASS_BODY()

	UFUNCTION(BlueprintPure, meta = (DisplayName = "Get CPU Brand Name", Keywords = "CPU brand"), Category = PlatformFunctions)
		static FString GetCPUBrandName();

	UFUNCTION(BlueprintPure, meta = (DisplayName = "Get CPU Vendor Name", Keywords = "CPU vendor"), Category = PlatformFunctions)
		static FString GetCPUVendorName();

	UFUNCTION(BlueprintPure, meta = (DisplayName = "Get GPU Brand Name", Keywords = "GPU brand"), Category = PlatformFunctions)
		static FString GetGPUBrandName();

	UFUNCTION(BlueprintPure, meta = (DisplayName = "Get Number of CPU Cores", Keywords = "CPU cores"), Category = PlatformFunctions)
		static int32 GetCPUCores();

	UFUNCTION(BlueprintPure, meta = (DisplayName = "Get Audio Device Name", Keywords = "Audio device"), Category = PlatformFunctions)
		static FString GetAudioDeviceName();

	UFUNCTION(BlueprintPure, meta = (DisplayName = "Get Monitors Count", Keywords = "Display"), Category = PlatformFunctions)
		static int32 GetMonitorsCount();

	UFUNCTION(BlueprintPure, meta = (DisplayName = "Get Primary Monitor", Keywords = "Display"), Category = PlatformFunctions)
		static int32 GetPrimaryMonitor();

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "Set Active Monitor", Keywords = "Display"), Category = PlatformFunctions)
		static bool SetActiveMonitor(int32 MonitorIndex);

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "Set Gamma", Keywords = "Display"), Category = PlatformFunctions)
		static void SetGamma(float Gamma);

	UFUNCTION(BlueprintPure, meta = (DisplayName = "Get Gamma", Keywords = "Display"), Category = PlatformFunctions)
		static float GetGamma();
};
